searchData={"items":[{"type":"module","title":"AbsintheHelpers.Constraints.Regex","doc":"Applies regex constraint on node data. This constraint can only be applied to String types.","ref":"AbsintheHelpers.Constraints.Regex.html"},{"type":"function","title":"AbsintheHelpers.Constraints.Regex.call/2","doc":"","ref":"AbsintheHelpers.Constraints.Regex.html#call/2"},{"type":"module","title":"AbsintheHelpers.Directives.Constraints","doc":"Defines a GraphQL directive for adding constraints to fields and arguments.\n\nSupports:\n- `:min`, `:max`: For numbers and string lengths\n- `:min_items`, `:max_items`: For lists\n- `:regex`: For strings\n\nApplicable to scalars (:string, :integer, :float, :decimal) and lists.\n\nExample:\n    field :username, :string, directives: [constraints: [min: 3, max: 20, regex: \"^[a-zA-Z]+$\"]]\n    arg :tags, list_of(:string), directives: [constraints: [max_items: 5, max: 10]]\n\nConstraints are automatically enforced during query execution.","ref":"AbsintheHelpers.Directives.Constraints.html"},{"type":"function","title":"AbsintheHelpers.Directives.Constraints.expand_constraints/2","doc":"","ref":"AbsintheHelpers.Directives.Constraints.html#expand_constraints/2"},{"type":"function","title":"AbsintheHelpers.Directives.Constraints.expand_deprecate/2","doc":"Add a deprecation (with an optional reason) to a node.","ref":"AbsintheHelpers.Directives.Constraints.html#expand_deprecate/2"},{"type":"function","title":"AbsintheHelpers.Directives.Constraints.pipeline/1","doc":"","ref":"AbsintheHelpers.Directives.Constraints.html#pipeline/1"},{"type":"module","title":"AbsintheHelpers.Phases.ApplyConstraints","doc":"Validates input nodes against constraints defined by the `constraints`\ndirective in your Absinthe schema. Constraints can be applied to fields\nand arguments, enforcing rules such as `min`, `max`, etc. These constraints\ncan be applied to both individual items and lists simultaneously.","ref":"AbsintheHelpers.Phases.ApplyConstraints.html"},{"type":"module","title":"Example usage - AbsintheHelpers.Phases.ApplyConstraints","doc":"Add this phase to your pipeline in your router:\n\n    pipeline =\n      config\n      |> Absinthe.Plug.default_pipeline(opts)\n      |> AbsintheHelpers.Phases.ApplyConstraints.add_to_pipeline(opts)\n\nAdd the constraints directive's prototype schema to your schema:\n\n    defmodule MyApp.Schema do\n      use Absinthe.Schema\n\n      @prototype_schema AbsintheHelpers.Directives.Constraints\n\n      directive :constraints do\n        on([:argument_definition, :field_definition, :input_field_definition])\n\n        arg(:min, :integer, description: \"Minimum value allowed\")\n        arg(:max, :integer, description: \"Maximum value allowed\")\n        arg(:min_items, :integer, description: \"Minimum number of items allowed in a list\")\n        arg(:max_items, :integer, description: \"Maximum number of items allowed in a list\")\n      end\n      # ...\n    end\n\nApply constraints to a field or argument:\n\n    field :my_list, list_of(:integer) do\n      directive(:constraints, [min_items: 2, max_items: 5, min: 1, max: 100])\n\n      resolve(&MyResolver.resolve/3)\n    end\n\n    field :my_field, :integer do\n      arg :my_arg, non_null(:string), directives: [constraints: [min: 10]]\n\n      resolve(&MyResolver.resolve/3)\n    end","ref":"AbsintheHelpers.Phases.ApplyConstraints.html#module-example-usage"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyConstraints.add_to_pipeline/2","doc":"","ref":"AbsintheHelpers.Phases.ApplyConstraints.html#add_to_pipeline/2"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyConstraints.flag_invalid/1","doc":"","ref":"AbsintheHelpers.Phases.ApplyConstraints.html#flag_invalid/1"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyConstraints.flag_invalid/2","doc":"","ref":"AbsintheHelpers.Phases.ApplyConstraints.html#flag_invalid/2"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyConstraints.flag_invalid/3","doc":"","ref":"AbsintheHelpers.Phases.ApplyConstraints.html#flag_invalid/3"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyConstraints.inherit_invalid/3","doc":"","ref":"AbsintheHelpers.Phases.ApplyConstraints.html#inherit_invalid/3"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyConstraints.put_flag/2","doc":"","ref":"AbsintheHelpers.Phases.ApplyConstraints.html#put_flag/2"},{"type":"module","title":"AbsintheHelpers.Phases.ApplyTransforms","doc":"The module identifies input nodes with transformation metadata and applies\nthem to the values. These transformations can be applied to both single-value\nnodes and lists of items.\n\nNew transformations can be added in the `lib/transforms/` directory, like\n`AbsintheHelpers.Transforms.ToInteger`, or within your own project, as long\nas they implement the same behaviour.","ref":"AbsintheHelpers.Phases.ApplyTransforms.html"},{"type":"module","title":"Example usage - AbsintheHelpers.Phases.ApplyTransforms","doc":"To add this phase to your pipeline, add the following to your router:\n\n    forward \"/graphql\",\n        to: Absinthe.Plug,\n        init_opts: [\n          schema: MyProject.Schema,\n          pipeline: {__MODULE__, :absinthe_pipeline},\n        ]\n\n    def absinthe_pipeline(config, opts) do\n      config\n      |> Absinthe.Plug.default_pipeline(opts)\n      |> AbsintheHelpers.Phases.ApplyTransforms.add_to_pipeline(opts)\n    end\n\nThen apply transforms on a schema field:\n\n    alias AbsintheHelpers.Transforms.ToInteger\n    alias AbsintheHelpers.Transforms.Trim\n    alias AbsintheHelpers.Transforms.Increment\n\n    field :employee_id, :id do\n      meta transforms: [Trim, ToInteger, {Increment, 3}]\n    end\n\nor on a list:\n\n    field :employee_ids, non_null(list_of(non_null(:id))) do\n      meta transforms: [Trim, ToInteger, {Increment, 3}]\n    end\n\nor on a schema arg:\n\n    field(:create_booking, :string) do\n      arg(:employee_id, non_null(:id),\n        __private__: [meta: [transforms: [Trim, ToInteger, {Increment, 3}]]]\n      )\n\n      resolve(&TestResolver.run/3)\n    end\n\nIn this case, both the `Trim`, `ToInteger`, and `Increment` will be applied\nto the `employee_id` field.","ref":"AbsintheHelpers.Phases.ApplyTransforms.html#module-example-usage"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyTransforms.add_to_pipeline/2","doc":"","ref":"AbsintheHelpers.Phases.ApplyTransforms.html#add_to_pipeline/2"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyTransforms.flag_invalid/1","doc":"","ref":"AbsintheHelpers.Phases.ApplyTransforms.html#flag_invalid/1"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyTransforms.flag_invalid/2","doc":"","ref":"AbsintheHelpers.Phases.ApplyTransforms.html#flag_invalid/2"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyTransforms.flag_invalid/3","doc":"","ref":"AbsintheHelpers.Phases.ApplyTransforms.html#flag_invalid/3"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyTransforms.inherit_invalid/3","doc":"","ref":"AbsintheHelpers.Phases.ApplyTransforms.html#inherit_invalid/3"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyTransforms.put_flag/2","doc":"","ref":"AbsintheHelpers.Phases.ApplyTransforms.html#put_flag/2"},{"type":"function","title":"AbsintheHelpers.Phases.ApplyTransforms.run/2","doc":"","ref":"AbsintheHelpers.Phases.ApplyTransforms.html#run/2"},{"type":"module","title":"AbsintheHelpers.Transforms.ToInteger","doc":"A transformation that converts string input values to integers in an Absinthe\nschema.\n\nAdd the transformation in your schema:\n\n    alias AbsintheHelpers.Transforms.ToInteger\n\n    field :employee_id, :id do\n      meta transforms: [ToInteger]\n    end","ref":"AbsintheHelpers.Transforms.ToInteger.html"},{"type":"function","title":"AbsintheHelpers.Transforms.ToInteger.call/2","doc":"","ref":"AbsintheHelpers.Transforms.ToInteger.html#call/2"},{"type":"module","title":"AbsintheHelpers.Transforms.Trim","doc":"A transformation that trims whitespace from string input values in an\nAbsinthe schema.","ref":"AbsintheHelpers.Transforms.Trim.html"},{"type":"module","title":"Example Usage - AbsintheHelpers.Transforms.Trim","doc":"Add the transformation to a field in your schema:\n\n    alias AbsintheHelpers.Transforms.Trim\n\n    field :username, :string do\n      meta transforms: [Trim]\n    end","ref":"AbsintheHelpers.Transforms.Trim.html#module-example-usage"},{"type":"function","title":"AbsintheHelpers.Transforms.Trim.call/2","doc":"","ref":"AbsintheHelpers.Transforms.Trim.html#call/2"},{"type":"extras","title":"Absinthe Helpers","doc":"# Absinthe Helpers\n\nThis package provides two key features:\n\n1. **constraints**: enforce validation rules (like `min`, `max`, etc.) on fields and arguments in your schema.\n2. **transforms**: apply custom transformations (like `Trim`, `ToInteger`, etc.) to input fields and arguments.","ref":"readme.html"},{"type":"extras","title":"Installation - Absinthe Helpers","doc":"Add `absinthe_helpers` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:absinthe_helpers, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen, run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Setup: adding constraints and transforms to your Absinthe pipeline - Absinthe Helpers","doc":"To set up both **constraints** and **transforms**, follow these steps:\n\n1. Add constraints and transforms to your Absinthe pipeline:\n\n```elixir\nforward \"/graphql\",\n    to: Absinthe.Plug,\n    init_opts: [\n      schema: MyProject.Schema,\n      pipeline: {__MODULE__, :absinthe_pipeline},\n    ]\n\ndef absinthe_pipeline(config, opts) do\n  config\n  |> Absinthe.Plug.default_pipeline(opts)\n  |> AbsintheHelpers.Phases.ApplyConstraints.add_to_pipeline(opts)\n  |> AbsintheHelpers.Phases.ApplyTransforms.add_to_pipeline(opts)\nend\n```\n\n2. Add constraints to your schema:\n\n```elixir\ndefmodule MyApp.Schema do\n  use Absinthe.Schema\n  @prototype_schema AbsintheHelpers.Directives.Constraints\n\n  directive :constraints do\n    on([:argument_definition, :field_definition, :input_field_definition])\n\n    arg(:min, :integer, description: \"Minimum value allowed\")\n    arg(:max, :integer, description: \"Maximum value allowed\")\n    arg(:min_items, :integer, description: \"Minimum number of items allowed in a list\")\n    arg(:max_items, :integer, description: \"Maximum number of items allowed in a list\")\n    arg(:regex, :string, description: \"Pattern to match for a string\")\n  end\n\n  query do\n  end\n\n  mutation do\n  end\n\n  # ...\nend\n```\n\n---","ref":"readme.html#setup-adding-constraints-and-transforms-to-your-absinthe-pipeline"},{"type":"extras","title":"Constraints - Absinthe Helpers","doc":"The `constraints` directive allows you to enforce validation rules on fields and arguments in your GraphQL schema. Constraints are applied at the schema level and are visible in the GraphQL schema, making them accessible to the frontend.","ref":"readme.html#constraints"},{"type":"extras","title":"Example: graphql schema with constraints - Absinthe Helpers","doc":"```graphql\n\"Overrides for location-specific service pricing.\"\ninput LocationOverrideInput {\n  duration: Int @constraints(min: 300, max: 43200)\n  price: Decimal @constraints(min: 0, max: 100000000)\n  priceType: ServicePriceType\n  locationId: ID!\n}\n```","ref":"readme.html#example-graphql-schema-with-constraints"},{"type":"extras","title":"How to use constraints - Absinthe Helpers","doc":"1. Apply constraints to a field or argument:\n\n```elixir\nfield :my_list, list_of(:integer) do\n  directive(:constraints, [min_items: 2, max_items: 5, min: 1, max: 100])\n\n  resolve(&MyResolver.resolve/3)\nend\n\nfield :my_field, :integer do\n  arg :my_arg, non_null(:string), directives: [constraints: [min: 10, regex: \"^[a-zA-Z]+$\"]]\n\n  resolve(&MyResolver.resolve/3)\nend\n```\n\n---","ref":"readme.html#how-to-use-constraints"},{"type":"extras","title":"Transforms - Absinthe Helpers","doc":"Transforms allow you to modify or coerce input values at runtime. You can apply these transformations to individual fields, lists, or arguments in your Absinthe schema.","ref":"readme.html#transforms"},{"type":"extras","title":"Example: applying transforms in your schema - Absinthe Helpers","doc":"1. Apply transforms directly to a field:\n\n```elixir\nalias AbsintheHelpers.Transforms.ToInteger\nalias AbsintheHelpers.Transforms.Trim\nalias AbsintheHelpers.Transforms.Increment\n\nfield :employee_id, :id do\n  meta transforms: [Trim, ToInteger, {Increment, 3}]\nend\n```\n\n2. Apply transforms to a list of values:\n\n```elixir\nfield :employee_ids, non_null(list_of(non_null(:id))) do\n  meta transforms: [Trim, ToInteger, {Increment, 3}]\nend\n```\n\n3. Apply transforms to an argument:\n\n```elixir\nfield(:create_booking, :string) do\n  arg(:employee_id, non_null(:id),\n    __private__: [meta: [transforms: [Trim, ToInteger, {Increment, 3}]]]\n  )\n\n  resolve(&TestResolver.run/3)\nend\n```","ref":"readme.html#example-applying-transforms-in-your-schema"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}